@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2014, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -28,6 +28,7 @@
 #include <QCryptographicHash>
 #include <QDateTime>
 #include <QDir>
+#include <QElapsedTimer>
 #include <QMimeData>
 #include <QRegularExpression>
 #include <QUrl>
@@ -66,6 +67,7 @@ const char dataFileSuffix[] = "_copyq.dat";
 const char noteFileSuffix[] = "_note.txt";
 
 const int defaultUpdateFocusItemsIntervalMs = 10000;
+const int batchItemUpdateIntervalMs = 100;
 
 const qint64 sizeLimit = 10 << 20;
 
@@ -197,7 +199,7 @@ bool saveItemFile(const QString &filePath, const QByteArray &bytes,
     return true;
 }
 
-bool canUseFile(QFileInfo &info)
+bool canUseFile(const QFileInfo &info)
 {
     return !info.isHidden() && !info.fileName().startsWith('.') && info.isReadable();
 }
@@ -244,16 +246,16 @@ BaseNameExtensionsList listFiles(const QStringList &files,
 }
 
 /// Load hash of all existing files to map (hash -> filename).
-QStringList listFiles(const QDir &dir, QDir::SortFlags sortFlags = QDir::NoSort)
+QStringList listFiles(const QDir &dir)
 {
     QStringList files;
 
     const QDir::Filters itemFileFilter = QDir::Files | QDir::Readable | QDir::Writable;
-    for ( const auto &fileName : dir.entryList(itemFileFilter, sortFlags) ) {
-        const QString path = dir.absoluteFilePath(fileName);
-        QFileInfo info(path);
+    // Get files ordered by name to achive same result on multiple platforms.
+    // NOTE: Sorting by modification time can be slow.
+    for ( const auto &info : dir.entryInfoList(itemFileFilter, QDir::Name) ) {
         if ( canUseFile(info) )
-            files.append(path);
+            files.append(info.absoluteFilePath());
     }
 
     return files;
@@ -417,7 +419,7 @@ FileWatcher::FileWatcher(
 
     bool ok;
     const int interval = qgetenv("COPYQ_SYNC_UPDATE_INTERVAL_MS").toInt(&ok);
-    m_updateTimer.setInterval(ok && interval > 0 ? interval : defaultUpdateFocusItemsIntervalMs);
+    m_interval = ok && interval > 0 ? interval : defaultUpdateFocusItemsIntervalMs;
 
     connect( &m_updateTimer, &QTimer::timeout,
              this, &FileWatcher::updateItems );
@@ -449,7 +451,7 @@ void FileWatcher::unlock()
     m_valid = true;
 }
 
-bool FileWatcher::createItemFromFiles(const QDir &dir, const BaseNameExtensions &baseNameWithExts, int targetRow)
+void FileWatcher::createItemFromFiles(const QDir &dir, const BaseNameExtensions &baseNameWithExts, int targetRow)
 {
     QVariantMap dataMap;
     QVariantMap mimeToExtension;
@@ -459,74 +461,111 @@ bool FileWatcher::createItemFromFiles(const QDir &dir, const BaseNameExtensions
     if ( !mimeToExtension.isEmpty() ) {
         dataMap.insert( mimeBaseName, QFileInfo(baseNameWithExts.baseName).fileName() );
         dataMap.insert(mimeExtensionMap, mimeToExtension);
-
-        if ( !createItem(dataMap, targetRow) )
-            return false;
+        createItem(dataMap, targetRow);
     }
-
-    return true;
 }
 
 void FileWatcher::createItemsFromFiles(const QDir &dir, const BaseNameExtensionsList &fileList)
 {
     for (const auto &baseNameWithExts : fileList) {
-        if ( !createItemFromFiles(dir, baseNameWithExts, 0)
-             || m_model->rowCount() >= m_maxItems )
-        {
+        if ( m_model->rowCount() >= m_maxItems )
             break;
-        }
+
+        createItemFromFiles(dir, baseNameWithExts, 0);
     }
 }
 
 void FileWatcher::updateItems()
 {
     if ( !lock() ) {
-        m_updateTimer.start();
+        m_updateTimer.start(m_interval);
         return;
     }
 
+    QElapsedTimer t;
+    t.start();
+
     m_lastUpdateTimeMs = QDateTime::currentMSecsSinceEpoch();
 
     const QDir dir(m_path);
-    const QStringList files = listFiles(dir, QDir::Time | QDir::Reversed);
-    BaseNameExtensionsList fileList = listFiles(files, m_formatSettings);
 
-    for ( int row = 0; row < m_model->rowCount(); ++row ) {
-        const QModelIndex index = m_model->index(row, 0);
-        const QString baseName = getBaseName(index);
+    if ( m_batchIndexData.isEmpty() ) {
+        const QStringList files = listFiles(dir);
+        m_fileList = listFiles(files, m_formatSettings);
+        m_batchIndexData = m_indexData;
 
-        int i = 0;
-        for ( i = 0; i < fileList.size() && fileList[i].baseName != baseName; ++i ) {}
+        // Sort so that top rows get updated first.
+        std::sort(
+            std::begin(m_batchIndexData), std::end(m_batchIndexData),
+            [](const IndexData &lhs, const IndexData &rhs){
+                return lhs.index.row() < rhs.index.row();
+            });
+
+        m_lastBatchIndex = -1;
+        if ( t.elapsed() > 100 )
+            log( QString("ItemSync: Files listed in %1 ms").arg(t.elapsed()) );
+    }
+
+    for ( int i = m_lastBatchIndex + 1; i < m_batchIndexData.size(); ++i ) {
+        const IndexData &indexData = m_batchIndexData[i];
+        const QPersistentModelIndex &index = indexData.index;
+        if ( !index.isValid() )
+            continue;
+        const QString baseName = indexData.baseName;
+        if ( baseName.isEmpty() )
+            continue;
+
+        int j = 0;
+        for ( j = 0; j < m_fileList.size() && m_fileList[j].baseName != baseName; ++j ) {}
 
         QVariantMap dataMap;
         QVariantMap mimeToExtension;
 
-        if ( i < fileList.size() ) {
-            updateDataAndWatchFile(dir, fileList[i], &dataMap, &mimeToExtension);
-            fileList.removeAt(i);
+        if ( j < m_fileList.size() ) {
+            updateDataAndWatchFile(dir, m_fileList[j], &dataMap, &mimeToExtension);
+            m_fileList.removeAt(j);
         }
 
         if ( mimeToExtension.isEmpty() ) {
-            m_model->removeRow(row--);
+            m_model->removeRow(index.row());
         } else {
             dataMap.insert(mimeBaseName, baseName);
             dataMap.insert(mimeExtensionMap, mimeToExtension);
             updateIndexData(index, dataMap);
         }
+
+        if ( t.elapsed() > 20 ) {
+            COPYQ_LOG_VERBOSE( QString("ItemSync: Items updated in %1 ms, last row %2/%3")
+                 .arg(t.elapsed())
+                 .arg(i + 1)
+                 .arg(m_batchIndexData.size()) );
+            m_lastBatchIndex = i;
+            unlock();
+            m_updateTimer.start(batchItemUpdateIntervalMs);
+            return;
+        }
     }
 
-    createItemsFromFiles(dir, fileList);
+    t.restart();
+
+    createItemsFromFiles(dir, m_fileList);
+
+    if ( t.elapsed() > 100 )
+        log( QString("ItemSync: Items created in %1 ms").arg(t.elapsed()) );
+
+    m_fileList.clear();
+    m_batchIndexData.clear();
 
     unlock();
 
     if (m_updatesEnabled)
-        m_updateTimer.start();
+        m_updateTimer.start(m_interval);
 }
 
 void FileWatcher::updateItemsIfNeeded()
 {
     const auto time = QDateTime::currentMSecsSinceEpoch();
-    if (time < m_lastUpdateTimeMs + m_updateTimer.interval())
+    if (time < m_lastUpdateTimeMs + m_interval)
         return;
 
     updateItems();
@@ -537,7 +576,7 @@ void FileWatcher::setUpdatesEnabled(bool enabled)
     m_updatesEnabled = enabled;
     if (enabled)
         updateItems();
-    else
+    else if ( m_batchIndexData.isEmpty() )
         m_updateTimer.stop();
 }
 
@@ -554,9 +593,13 @@ void FileWatcher::onDataChanged(const QModelIndex &a, const QModelIndex &b)
 void FileWatcher::onRowsRemoved(const QModelIndex &, int first, int last)
 {
     for ( const auto &index : indexList(first, last) ) {
-        Q_ASSERT(index.isValid());
+        if ( !index.isValid() )
+            continue;
+
         IndexDataList::iterator it = findIndexData(index);
-        Q_ASSERT( it != m_indexData.end() );
+        if ( it == m_indexData.end() )
+            continue;
+
         if ( isOwnBaseName(it->baseName) )
             removeFilesForRemovedIndex(m_path, index);
         m_indexData.erase(it);
@@ -576,16 +619,22 @@ FileWatcher::IndexData &FileWatcher::indexData(const QModelIndex &index)
     return *it;
 }
 
-bool FileWatcher::createItem(const QVariantMap &dataMap, int targetRow)
+void FileWatcher::createItem(const QVariantMap &dataMap, int targetRow)
 {
     const int row = qMax( 0, qMin(targetRow, m_model->rowCount()) );
-    if ( m_model->insertRow(row) ) {
-        const QModelIndex &index = m_model->index(row, 0);
-        updateIndexData(index, dataMap);
-        return true;
-    }
+    if ( !m_model->insertRow(row) )
+        return;
 
-    return false;
+    // Find index if it was moved after inserted.
+    const int rows = m_model->rowCount();
+    for ( int i = 0; i < rows; ++i ) {
+        const int row2 = (row + i) % rows;
+        auto index = m_model->index(row2, 0);
+        if ( getBaseName(index).isEmpty() ) {
+            updateIndexData(index, dataMap);
+            return;
+        }
+    }
 }
 
 void FileWatcher::updateIndexData(const QModelIndex &index, const QVariantMap &itemData)
@@ -594,7 +643,8 @@ void FileWatcher::updateIndexData(const QModelIndex &index, const QVariantMap &i
 
     // Item base name is non-empty.
     const QString baseName = getBaseName(index);
-    Q_ASSERT( !baseName.isEmpty() );
+    if ( baseName.isEmpty() )
+        return;
 
     const QVariantMap mimeToExtension = itemData.value(mimeExtensionMap).toMap();
 
@@ -767,7 +817,8 @@ void FileWatcher::updateDataAndWatchFile(const QDir &dir, const BaseNameExtensio
     const QString basePath = dir.absoluteFilePath(baseNameWithExts.baseName);
 
     for (const auto &ext : baseNameWithExts.exts) {
-        Q_ASSERT( !ext.format.isEmpty() );
+        if ( ext.format.isEmpty() )
+            continue;
 
         const QString fileName = basePath + ext.extension;
 
@@ -775,8 +826,9 @@ void FileWatcher::updateDataAndWatchFile(const QDir &dir, const BaseNameExtensio
         if ( !f.open(QIODevice::ReadOnly) )
             continue;
 
-        if ( ext.extension == dataFileSuffix && deserializeData(dataMap, f.readAll()) ) {
-            mimeToExtension->insert(mimeUnknownFormats, dataFileSuffix);
+        if ( ext.extension == dataFileSuffix ) {
+            if ( deserializeData(dataMap, f.readAll()) )
+                mimeToExtension->insert(mimeUnknownFormats, dataFileSuffix);
         } else if ( f.size() > sizeLimit || ext.format.startsWith(mimeNoFormat)
                     || dataMap->contains(ext.format) )
         {
