@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2014, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -340,6 +340,16 @@ void setNormalStretchFixedColumns(QTableWidget *table, int normalColumn, int str
     table->resizeColumnToContents(normalColumn);
 }
 
+bool hasOnlyInternalData(const QVariantMap &data)
+{
+    for (auto it = data.constBegin(); it != data.constEnd(); ++it) {
+        const auto &format = it.key();
+        if ( !format.startsWith(COPYQ_MIME_PREFIX) )
+            return false;
+    }
+    return true;
+}
+
 } // namespace
 
 ItemSync::ItemSync(const QString &label, const QString &icon, ItemWidget *childItem)
@@ -539,12 +549,9 @@ QVariantMap ItemSyncSaver::copyItem(const QAbstractItemModel &, const QVariantMa
     QVariantMap copiedItemData = itemData;
     copiedItemData.insert(mimeSyncPath, m_tabPath);
 
-    // Add text/plain and text/uri-list if not present.
-    bool updateUriData = !copiedItemData.contains(mimeUriList);
-    bool updateTextData = !copiedItemData.contains(mimeText);
-    if (updateUriData || updateTextData) {
+    // Add text/uri-list if no data are present.
+    if ( hasOnlyInternalData(copiedItemData) ) {
         QByteArray uriData;
-        QByteArray textData;
 
         const QVariantMap mimeToExtension = itemData.value(mimeExtensionMap).toMap();
         const QString basePath = m_tabPath + '/' + itemData.value(mimeBaseName).toString();
@@ -552,31 +559,14 @@ QVariantMap ItemSyncSaver::copyItem(const QAbstractItemModel &, const QVariantMa
         for (const auto &extension : mimeToExtension) {
             const QString filePath = basePath + extension.toString();
 
-            if (updateUriData) {
-                if ( !uriData.isEmpty() )
-                    uriData.append("\n");
-                uriData.append( QUrl::fromLocalFile(filePath).toEncoded() );
-            }
-
-            if (updateTextData) {
-                if ( !textData.isEmpty() )
-                    textData.append("\n");
-                textData.append( filePath.toUtf8()
-                                 .replace('\\', "\\\\")
-                                 .replace('\n', "\\n")
-                                 .replace('\r', "\\r") );
-            }
+            if ( !uriData.isEmpty() )
+                uriData.append("\n");
+            uriData.append( QUrl::fromLocalFile(filePath).toEncoded() );
         }
 
         QVariantMap noSaveData;
-        if (updateUriData) {
-            noSaveData.insert(mimeUriList, FileWatcher::calculateHash(uriData));
-            copiedItemData.insert(mimeUriList, uriData);
-        }
-        if (updateTextData) {
-            noSaveData.insert(mimeText, FileWatcher::calculateHash(textData));
-            copiedItemData.insert(mimeText, textData);
-        }
+        noSaveData.insert(mimeUriList, FileWatcher::calculateHash(uriData));
+        copiedItemData.insert(mimeUriList, uriData);
         copiedItemData.insert(mimeNoSave, noSaveData);
     }
 
@@ -807,14 +797,17 @@ ItemScriptable *ItemSyncLoader::scriptableObject()
 
 void ItemSyncLoader::onBrowseButtonClicked()
 {
-    QTableWidget *t = ui->tableWidgetSyncTabs;
-
     QObject *button = sender();
-    Q_ASSERT(button != nullptr);
+    if (button == nullptr)
+        return;
+
+    QTableWidget *t = ui->tableWidgetSyncTabs;
 
     int row = 0;
     for ( ; row < t->rowCount() && t->cellWidget(row, syncTabsTableColumns::browse) != button; ++row ) {}
-    Q_ASSERT(row != t->rowCount());
+    Q_ASSERT( row == t->rowCount() );
+    if ( row == t->rowCount() )
+        return;
 
     QTableWidgetItem *item = t->item(row, syncTabsTableColumns::path);
     const QString path =
