@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2014, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -502,9 +502,14 @@ void ItemSyncTests::notes()
 
     // One new file for notes.
     const QStringList files2 = dir1.files();
-    const QSet<QString> filesDiff = files2.toSet() - files1.toSet();
-    QCOMPARE( filesDiff.size(), 1 );
-    const QString fileNote = *filesDiff.begin();
+    QCOMPARE( files2.size(), files1.size() + 1 );
+    QString fileNote;
+    for (const auto &file : files2) {
+        if ( !files1.contains(file) ) {
+            fileNote = file;
+            break;
+        }
+    }
 
     // Read file with the notes.
     FilePtr file = dir1.file(fileNote);
@@ -639,3 +644,42 @@ void ItemSyncTests::getAbsoluteFilePath()
 
     RUN(args << code, dir1.filePath("test1"));
 }
+
+void ItemSyncTests::addItemsWhenFull()
+{
+    TestDir dir1(1);
+    const QString tab1 = testTab(1);
+    const Args args = Args() << "separator" << ";" << "tab" << tab1;
+    RUN(args << "show" << tab1, "");
+
+    RUN("config" << "maxitems" << "2", "2\n");
+    RUN(args << "add" << "A" << "B", "");
+    RUN(args << "read" << "0" << "1" << "2", "B;A;");
+    RUN(args << "add" << "C", "");
+    RUN(args << "read" << "0" << "1" << "2", "C;B;");
+}
+
+void ItemSyncTests::addItemsWhenFullOmitDeletingNotOwned()
+{
+    TestDir dir1(1);
+    const QString tab1 = testTab(1);
+    const Args args = Args() << "separator" << ";" << "tab" << tab1;
+    RUN(args << "show" << tab1, "");
+
+    RUN("config" << "maxitems" << "1", "1\n");
+
+    const QString testFileName1 = "test1.txt";
+    createFile(dir1, testFileName1, "NOT-OWNED");
+    WAIT_ON_OUTPUT(args << "size", "1\n");
+    RUN(args << "read" << "0" << "1", "NOT-OWNED;");
+
+    RUN(args << "add" << "A", "");
+    RUN(args << "read" << "0" << "1", "A;");
+    RUN(args << "remove" << "0", "");
+
+    WAIT_ON_OUTPUT(args << "size", "1\n");
+    RUN(args << "read" << "0" << "1", "NOT-OWNED;");
+
+    FilePtr f1(dir1.file(testFileName1));
+    QVERIFY(f1->exists());
+}
