@@ -47,7 +47,7 @@
 #include <QtScript/QScriptValue>
 
 //! [0]
-class ByteArrayPrototype : public QObject, public QScriptable
+class ByteArrayPrototype final : public QObject, public QScriptable
 {
 Q_OBJECT
 public:
@@ -71,6 +71,8 @@ public slots:
     QScriptValue valueOf() const;
     int size() const;
 
+    QString text() const;
+
 private:
     QByteArray *thisByteArray() const;
 };
