@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -62,12 +62,12 @@ QCoreApplication *createClientApplication(int &argc, char **argv, const QStringL
         QGuiApplication::setDesktopSettingsAware(false);
         const auto app = platformNativeInterface()
                 ->createClipboardProviderApplication(argc, argv);
-        setCurrentThreadName(arguments[1]);
+        setLogLabel(arguments[1].toUtf8());
         return app;
     }
 
     const auto app = platformNativeInterface()->createClientApplication(argc, argv);
-    setCurrentThreadName("Client");
+    setLogLabel("Client");
     return app;
 }
 
