@@ -727,10 +727,19 @@ void ClipboardServer::shortcutActivated(QxtGlobalShortcut *shortcut)
     const QMap<QxtGlobalShortcut*, Command>::const_iterator it =
             m_shortcutActions.constFind(shortcut);
     if ( it != m_shortcutActions.constEnd() ) {
-        QVariantMap data;
         const QString shortcutText = portableShortcutText(shortcut->shortcut());
-        data.insert(mimeShortcut, shortcutText.toUtf8());
-        m_wnd->action(data, it.value(), QModelIndex());
+        const Command &command = it.value();
+
+        // If global shortcut for a menu command is triggered when the main window
+        // is active, the command will be executed as if it has been trigger from
+        // menu - i.e. with item selection and item data available.
+        if ( command.inMenu && m_wnd->isActiveWindow() && m_wnd->triggerMenuCommand(command, shortcutText) ) {
+            COPYQ_LOG("Global shortcut command triggered as a menu command");
+        } else {
+            QVariantMap data;
+            data.insert(mimeShortcut, shortcutText.toUtf8());
+            m_wnd->action(data, command, QModelIndex());
+        }
     }
 #endif
 }
