@@ -136,6 +136,16 @@ struct save_filter_history : Config<bool> {
     static QString name() { return "save_filter_history"; }
 };
 
+struct filter_regular_expression : Config<bool> {
+    static QString name() { return "filter_regular_expression"; }
+    static Value defaultValue() { return true; }
+};
+
+struct filter_case_insensitive : Config<bool> {
+    static QString name() { return "filter_case_insensitive"; }
+    static Value defaultValue() { return true; }
+};
+
 struct always_on_top : Config<bool> {
     static QString name() { return "always_on_top"; }
 };
@@ -204,6 +214,11 @@ struct text_tab_width : Config<int> {
     static Value defaultValue() { return 8; }
 };
 
+struct activate_item_with_single_click : Config<bool> {
+    static QString name() { return "activate_item_with_single_click"; }
+    static Value defaultValue() { return false; }
+};
+
 struct activate_closes : Config<bool> {
     static QString name() { return "activate_closes"; }
     static Value defaultValue() { return true; }
@@ -347,6 +362,17 @@ struct save_on_app_deactivated : Config<bool> {
     static Value defaultValue() { return true; }
 };
 
+struct native_menu_bar : Config<bool> {
+    static QString name() { return "native_menu_bar"; }
+#ifdef Q_OS_MAC
+    // Native menu bar does't show on macOS.
+    // See: https://github.com/hluk/CopyQ/issues/1444
+    static Value defaultValue() { return false; }
+#else
+    static Value defaultValue() { return true; }
+#endif
+};
+
 } // namespace Config
 
 class AppConfig final
