@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -49,8 +49,8 @@ QByteArray logLevelLabel(LogLevel level);
 
 void log(const QString &text, LogLevel level = LogNote);
 
-void setCurrentThreadName(const QString &name);
+void setLogLabel(const QByteArray &name);
 
-QByteArray currentThreadLabel();
+QByteArray &logLabel();
 
 #endif // LOG_H
