@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -30,6 +30,7 @@
 #include <QAbstractButton>
 #include <QFile>
 #include <QMessageBox>
+#include <QShortcut>
 
 #include <memory>
 
@@ -73,6 +74,11 @@ ActionDialog::ActionDialog(QWidget *parent)
     ui->comboBoxCommands->setFont( ui->commandEdit->commandFont() );
     ui->commandEdit->setFocus();
 
+    auto shortcut = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_P), this);
+    connect(shortcut, &QShortcut::activated, this, &ActionDialog::previousCommand);
+    shortcut = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_N), this);
+    connect(shortcut, &QShortcut::activated, this, &ActionDialog::nextCommand);
+
     connect(ui->buttonBox, &QDialogButtonBox::clicked,
             this, &ActionDialog::onButtonBoxClicked);
     connect(ui->comboBoxCommands, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
@@ -295,6 +301,18 @@ void ActionDialog::onSeparatorEditTextEdited(const QString &)
     setChangedByUser(ui->separatorEdit);
 }
 
+void ActionDialog::nextCommand()
+{
+    const int index = ui->comboBoxCommands->currentIndex();
+    ui->comboBoxCommands->setCurrentIndex(index - 1);
+}
+
+void ActionDialog::previousCommand()
+{
+    const int index = ui->comboBoxCommands->currentIndex();
+    ui->comboBoxCommands->setCurrentIndex(index + 1);
+}
+
 void ActionDialog::acceptCommand()
 {
     const auto command = this->command();
