@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -78,6 +78,9 @@ private:
     void onComboBoxOutputTabEditTextChanged(const QString &text);
     void onSeparatorEditTextEdited(const QString &text);
 
+    void previousCommand();
+    void nextCommand();
+
     void acceptCommand();
     QVariant createCurrentItemData();
     void saveCurrentCommandToHistory();
