@@ -274,7 +274,7 @@ ClipboardBrowser::ClipboardBrowser(
     setEditTriggers(QAbstractItemView::NoEditTriggers);
     setAlternatingRowColors(true);
 
-    initSingleShotTimer( &m_timerSave, 30000, this, &ClipboardBrowser::saveItems );
+    initSingleShotTimer( &m_timerSave, 0, this, &ClipboardBrowser::saveItems );
     initSingleShotTimer( &m_timerEmitItemCount, 0, this, &ClipboardBrowser::emitItemCount );
     initSingleShotTimer( &m_timerUpdateSizes, 0, this, &ClipboardBrowser::updateSizes );
     initSingleShotTimer( &m_timerUpdateCurrent, 0, this, &ClipboardBrowser::updateCurrent );
@@ -562,13 +562,13 @@ void ClipboardBrowser::connectModelAndDelegate()
 
     // Save on change
     connect( &m, &QAbstractItemModel::rowsInserted,
-             this, &ClipboardBrowser::delayedSaveItems );
+             this, [this]() { delayedSaveItems(m_sharedData->saveDelayMsOnItemAdded); } );
     connect( &m, &QAbstractItemModel::rowsRemoved,
-             this, &ClipboardBrowser::delayedSaveItems );
+             this, [this]() { delayedSaveItems(m_sharedData->saveDelayMsOnItemRemoved); } );
     connect( &m, &QAbstractItemModel::rowsMoved,
-             this, &ClipboardBrowser::delayedSaveItems );
+             this, [this]() { delayedSaveItems(m_sharedData->saveDelayMsOnItemMoved); } );
     connect( &m, &QAbstractItemModel::dataChanged,
-             this, &ClipboardBrowser::delayedSaveItems );
+             this, [this]() { delayedSaveItems(m_sharedData->saveDelayMsOnItemModified); } );
 
     connect( &d, &ItemDelegate::itemWidgetCreated,
              this, &ClipboardBrowser::itemWidgetCreated );
@@ -633,6 +633,9 @@ void ClipboardBrowser::preload(int pixels, bool above, const QModelIndex &start)
     QElapsedTimer t;
     t.start();
 
+    if ( m_timerUpdateSizes.isActive() )
+        updateSizes();
+
     const int s = spacing();
     const int direction = above ? -1 : 1;
     int row = start.row();
@@ -898,7 +901,7 @@ void ClipboardBrowser::onEditorSave()
     }
 
     focusEditedIndex();
-    saveItems();
+    delayedSaveItems(m_sharedData->saveDelayMsOnItemEdited);
 }
 
 void ClipboardBrowser::onEditorCancel()
@@ -1293,7 +1296,6 @@ void ClipboardBrowser::itemModified(const QByteArray &bytes, const QString &mime
             m_sharedData->itemFactory->setData(dataMap, index, &m);
         else
             add(dataMap);
-        saveItems();
     }
 }
 
@@ -1628,7 +1630,6 @@ bool ClipboardBrowser::add(const QVariantMap &data, int row)
         m.insertItem(data, newRow);
     }
 
-    saveItems();
     return true;
 }
 
@@ -1715,13 +1716,13 @@ void ClipboardBrowser::moveToClipboard()
     moveToClipboard( selectionModel()->selectedIndexes() );
 }
 
-void ClipboardBrowser::delayedSaveItems()
+void ClipboardBrowser::delayedSaveItems(int ms)
 {
-    if ( !isLoaded() || tabName().isEmpty() )
+    if ( !isLoaded() || tabName().isEmpty() || ms < 0 )
         return;
 
-    if ( !m_timerSave.isActive() )
-        m_timerSave.start();
+    if ( !m_timerSave.isActive() || ms < m_timerSave.remainingTime() )
+        m_timerSave.start(ms);
 
     emit itemsChanged(this);
 }
@@ -1733,6 +1734,8 @@ void ClipboardBrowser::updateSizes()
         return;
     }
 
+    m_timerUpdateSizes.stop();
+
     m_resizing = true;
     updateItemMaximumSize();
     updateEditorGeometry();
@@ -1757,15 +1760,6 @@ void ClipboardBrowser::saveUnsavedItems()
         saveItems();
 }
 
-void ClipboardBrowser::purgeItems()
-{
-    if ( tabName().isEmpty() )
-        return;
-
-    removeItems(tabName());
-    m_timerSave.stop();
-}
-
 const QString ClipboardBrowser::selectedText() const
 {
     QString result;
