@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -34,7 +34,6 @@
 #include "gui/theme.h"
 #include "item/itemeditor.h"
 #include "item/itemdelegate.h"
-#include "platform/platformnativeinterface.h"
 
 #include <QAbstractScrollArea>
 #include <QAction>
@@ -47,19 +46,6 @@
 #include <QSettings>
 #include <QTemporaryFile>
 
-namespace {
-
-QString themePrefix()
-{
-#ifdef COPYQ_THEME_PREFIX
-    return COPYQ_THEME_PREFIX;
-#else
-    return platformNativeInterface()->themePrefix();
-#endif
-}
-
-} // namespace
-
 ConfigTabAppearance::ConfigTabAppearance(QWidget *parent)
     : QWidget(parent)
     , ui(new Ui::ConfigTabAppearance)
@@ -225,14 +211,7 @@ void ConfigTabAppearance::onComboBoxThemesActivated(const QString &text)
     if ( text.isEmpty() )
         return;
 
-    QString fileName = defaultUserThemePath() + "/" + text + ".ini";
-    if ( !QFile(fileName).exists() ) {
-        fileName = themePrefix();
-        if ( fileName.isEmpty() || !QFile(fileName).exists() )
-            return;
-        fileName.append("/" + text + ".ini");
-    }
-
+    const QString fileName = findThemeFile(text + ".ini");
     QSettings settings(fileName, QSettings::IniFormat);
     loadTheme(settings);
 }
@@ -256,18 +235,8 @@ void ConfigTabAppearance::updateThemes()
     ui->comboBoxThemes->clear();
     ui->comboBoxThemes->addItem(QString());
 
-    const QString userThemesPath = defaultUserThemePath();
-    QDir themesDir(userThemesPath);
-    if ( themesDir.mkpath(".") )
-        addThemes(userThemesPath);
-
-    const QByteArray customThemsPath = qgetenv("COPYQ_THEME_PREFIX");
-    if ( !customThemsPath.isEmpty() )
-        addThemes(QString::fromLocal8Bit(customThemsPath));
-
-    const QString themesPath = themePrefix();
-    if ( !themesPath.isEmpty() )
-        addThemes(themesPath);
+    for (const QString &path : themePaths())
+        addThemes(path);
 }
 
 void ConfigTabAppearance::addThemes(const QString &path)
@@ -300,8 +269,10 @@ void ConfigTabAppearance::updateStyle()
 void ConfigTabAppearance::fontButtonClicked(QObject *button)
 {
     QFont font = m_theme.themeFontFromString( button->property("VALUE").toString() );
-    QFontDialog dialog(font, this);
-    dialog.setOptions(dialog.options() | QFontDialog::DontUseNativeDialog);
+    QFontDialog dialog(this);
+    dialog.setOption(QFontDialog::DontUseNativeDialog);
+    // WORKAROUND: DontUseNativeDialog must be set before current font (QTBUG-79637).
+    dialog.setCurrentFont(font);
     if ( dialog.exec() == QDialog::Accepted ) {
         font = dialog.selectedFont();
         button->setProperty( "VALUE", font.toString() );
@@ -397,14 +368,6 @@ void ConfigTabAppearance::updateFontButtons()
     }
 }
 
-QString ConfigTabAppearance::defaultUserThemePath() const
-{
-    QSettings settings(QSettings::IniFormat, QSettings::UserScope,
-                       QCoreApplication::organizationName(),
-                       QCoreApplication::applicationName());
-    return QDir::cleanPath(settings.fileName() + "/../themes");
-}
-
 QIcon ConfigTabAppearance::createThemeIcon(const QString &fileName)
 {
     QSettings settings(fileName, QSettings::IniFormat);
@@ -477,10 +440,8 @@ void ConfigTabAppearance::decoratePreview()
 
     const QString searchFor = tr("item", "Search expression in preview in Appearance tab.");
 
-    c->addItems( QStringList()
-                 << tr("Search string is %1.").arg( quoteString(searchFor) )
-                 << tr("Select an item and\n"
-                       "press F2 to edit.") );
+    c->add( tr("Search string is %1.").arg(quoteString(searchFor)) );
+    c->add( tr("Select an item and\npress F2 to edit.") );
     for (int i = 1; i <= 20; ++i)
         c->add( tr("Example item %1").arg(i), -1 );
 
@@ -491,7 +452,7 @@ void ConfigTabAppearance::decoratePreview()
     model->setData(index, dataMap, contentType::updateData);
 
     // Highlight found text but don't filter out any items.
-    c->filterItems( QRegularExpression(QString("|") + searchFor, QRegularExpression::CaseInsensitiveOption) );
+    c->filterItems( QRegularExpression(QString("^|") + searchFor, QRegularExpression::CaseInsensitiveOption) );
 
     QAction *act;
 
