@@ -54,6 +54,8 @@ const char imagesRecourcePath[] = ":/images/";
 /// Up to this value of background lightness, icon color will be lighter.
 const int lightThreshold = 100;
 
+bool sessionIconTagEnabledFlag = true;
+
 QPointer<QObject> activePaintDevice;
 
 QIcon fromTheme(const QString &name)
@@ -224,9 +226,9 @@ QPixmap appPixmap(const QString &iconSuffix, QSize size)
     return pix;
 }
 
-void replaceColor(QPixmap *pix, const QString &iconSuffix, const QColor &targetColor)
+void replaceColor(QPixmap *pix, const QColor &targetColor)
 {
-    auto pix2 = appPixmap("_mask" + iconSuffix, pix->size());
+    auto pix2 = appPixmap("_mask", pix->size());
 
     {
         QPainter p1(&pix2);
@@ -239,6 +241,18 @@ void replaceColor(QPixmap *pix, const QString &iconSuffix, const QColor &targetC
     p.drawPixmap(0, 0, pix2);
 }
 
+void disableIcon(QPixmap *pix)
+{
+    QPixmap pix2(pix->size());
+    pix2.fill(Qt::transparent);
+    {
+        QPainter p(&pix2);
+        p.setOpacity(0.7);
+        p.drawPixmap(0, 0, *pix);
+    }
+    *pix = pix2;
+}
+
 QPixmap drawFontIcon(ushort id, int w, int h, const QColor &color)
 {
     const auto cacheKey = QString("id:%1|%2x%3|%4")
@@ -519,9 +533,8 @@ private:
 class AppIconEngine final : public BaseIconEngine
 {
 public:
-    AppIconEngine(AppIconType iconType)
+    AppIconEngine()
         : BaseIconEngine(sessionIconTagVariable(), sessionIconTagColor())
-        , m_iconType(iconType)
     {
     }
 
@@ -536,11 +549,11 @@ public:
         const bool useColoredIcon = !hasNormalIcon();
         const auto sessionColor = useColoredIcon ? sessionIconColor() : QColor();
 
-        const auto cacheKey = QString("app:%1|%2|%3x%4")
-                .arg(m_iconType)
+        const auto cacheKey = QString("app:%1|%2x%3|%4")
                 .arg(sessionColor.name())
                 .arg(size.width())
-                .arg(size.height());
+                .arg(size.height())
+                .arg(sessionIconTagEnabledFlag);
 
         {
             QPixmap pixmap;
@@ -548,21 +561,18 @@ public:
                 return pixmap;
         }
 
-        const bool running = m_iconType == AppIconRunning;
-        const auto suffix = running ? QLatin1String("-busy") : QLatin1String("");
-
-        auto pix = appPixmap(suffix, size);
+        auto pix = appPixmap(QString(), size);
 
         if ( sessionColor.isValid() )
-            replaceColor(&pix, suffix, sessionColor);
+            replaceColor(&pix, sessionColor);
+
+        if (!sessionIconTagEnabledFlag)
+            disableIcon(&pix);
 
         QPixmapCache::insert(cacheKey, pix);
 
         return pix;
     }
-
-private:
-    AppIconType m_iconType;
 };
 
 class IconEngine final
@@ -577,9 +587,9 @@ public:
         return QIcon( new ImageIconEngine(iconName, iconId, tag, tagColor) );
     }
 
-    static QIcon createIcon(AppIconType iconType)
+    static QIcon createIcon()
     {
-        return QIcon( new AppIconEngine(iconType) );
+        return QIcon( new AppIconEngine() );
     }
 
 private:
@@ -644,9 +654,9 @@ QPixmap createPixmap(unsigned short id, const QColor &color, int size)
     return pixmap;
 }
 
-QIcon appIcon(AppIconType iconType)
+QIcon appIcon()
 {
-    return IconEngine::createIcon(iconType);
+    return IconEngine::createIcon();
 }
 
 void setActivePaintDevice(QObject *device)
@@ -691,6 +701,11 @@ void setSessionIconTagColor(QColor color)
     sessionIconTagColorVariable() = color;
 }
 
+void setSessionIconEnabled(bool enabled)
+{
+    sessionIconTagEnabledFlag = enabled;
+}
+
 QColor sessionIconColor()
 {
     return ::sessionIconColorVariable();
