@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -165,7 +165,7 @@ IconSelectDialog::IconSelectDialog(const QString &defaultIcon, QWidget *parent)
     , m_iconList(new IconListWidget(this))
     , m_selectedIcon(defaultIcon)
 {
-    setWindowTitle( tr("CopyQ Select Icon") );
+    setWindowTitle( tr("Select Icon") );
 
     connect( m_iconList, &QAbstractItemView::activated,
              this, &IconSelectDialog::onIconListItemActivated );
