@@ -46,6 +46,7 @@ class ConfigurationManager;
 class Notification;
 class QAction;
 class QMimeData;
+class Tabs;
 class Theme;
 class TrayMenu;
 class ToolBar;
@@ -196,6 +197,8 @@ public:
     /** Set current tab. */
     bool setCurrentTab(int index);
 
+    bool focusPrevious();
+
     /** Open tab group renaming dialog. */
     void openRenameTabGroupDialog(const QString &name);
     /** Remove all tab in group. */
@@ -356,6 +359,8 @@ public:
             const Command &cmd,
             const QModelIndex &outputIndex);
 
+    bool triggerMenuCommand(const Command &command, const QString &triggeredShortcut);
+
     void runInternalAction(Action *action);
     bool isInternalActionId(int id) const;
 
@@ -538,7 +543,7 @@ private:
 
     void reloadBrowsers();
 
-    ClipboardBrowserPlaceholder *createTab(const QString &name, TabNameMatching nameMatch);
+    ClipboardBrowserPlaceholder *createTab(const QString &name, TabNameMatching nameMatch, const Tabs &tabs);
 
     int findTabIndexExactMatch(const QString &name);
 
@@ -622,14 +627,17 @@ private:
     bool toggleMenu(TrayMenu *menu);
 
     bool exportDataFrom(const QString &fileName, const QStringList &tabs, bool exportConfiguration, bool exportCommands);
-    bool exportDataV3(QDataStream *out, const QStringList &tabs, bool exportConfiguration, bool exportCommands);
+    bool exportDataV4(QDataStream *out, const QStringList &tabs, bool exportConfiguration, bool exportCommands);
     bool importDataV3(QDataStream *in, ImportOptions options);
+    bool importDataV4(QDataStream *in, ImportOptions options);
 
     const Theme &theme() const;
 
     Action *runScript(const QString &script, const QVariantMap &data = QVariantMap());
 
     void activateCurrentItemHelper();
+    void onItemClicked();
+    void onItemDoubleClicked();
 
     ConfigurationManager *cm;
     Ui::MainWindow *ui;
@@ -692,6 +700,7 @@ private:
     PlatformClipboardPtr m_clipboard;
 
     bool m_isActiveWindow = false;
+    bool m_singleClickActivate = 0;
 };
 
 #endif // MAINWINDOW_H
