@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -22,6 +22,7 @@
 #include "common/contenttype.h"
 #include "common/common.h"
 #include "common/display.h"
+#include "common/mimetypes.h"
 #include "common/textdata.h"
 #include "common/timer.h"
 #include "gui/icons.h"
@@ -81,19 +82,19 @@ TrayMenu::TrayMenu(QWidget *parent)
     m_clipboardItemActionsSeparator = addSeparator();
     m_customActionsSeparator = addSeparator();
     initSingleShotTimer( &m_timerUpdateActiveAction, 0, this, &TrayMenu::updateActiveAction );
+    setAttribute(Qt::WA_InputMethodEnabled);
 }
 
-void TrayMenu::addClipboardItemAction(const QModelIndex &index, bool showImages)
+void TrayMenu::addClipboardItemAction(const QVariantMap &data, bool showImages)
 {
     // Show search text at top of the menu.
     if ( m_clipboardItemActionCount == 0 && m_searchText.isEmpty() )
         setSearchMenuItem( m_viMode ? tr("Press '/' to search") : tr("Type to search") );
 
-    const QVariantMap data = index.data(contentType::data).toMap();
     QAction *act = addAction(QString());
     act->setProperty(propertyClipboardItemAction, true);
 
-    act->setData(index.data(contentType::data));
+    act->setData(data);
 
     insertAction(m_clipboardItemActionsSeparator, act);
 
@@ -135,6 +136,15 @@ void TrayMenu::addClipboardItemAction(const QModelIndex &index, bool showImages)
         }
     }
 
+    if ( act->icon().isNull() ) {
+        const QString icon = data.value(mimeIcon).toString();
+        if ( !icon.isEmpty() ) {
+            const QColor color = getDefaultIconColor(*this);
+            const QString tag = data.value(COPYQ_MIME_PREFIX "item-tag").toString();
+            act->setIcon( iconFromFile(icon, tag, color) );
+        }
+    }
+
     connect(act, &QAction::triggered, this, &TrayMenu::onClipboardItemActionTriggered);
 
     updateActiveAction();
@@ -254,6 +264,8 @@ void TrayMenu::mousePressEvent(QMouseEvent *event)
 
 void TrayMenu::showEvent(QShowEvent *event)
 {
+    search(QString());
+
     // If appmenu is used to handle the menu, most events won't be received
     // so search won't work.
     // This shows the search menu item only if show event is received.
@@ -285,6 +297,13 @@ void TrayMenu::leaveEvent(QEvent *event)
     setActiveAction(action);
 }
 
+void TrayMenu::inputMethodEvent(QInputMethodEvent *event)
+{
+    if (!event->commitString().isEmpty())
+        search(m_searchText + event->commitString());
+    event->ignore();
+}
+
 void TrayMenu::clearActionsWithProperty(const char *property)
 {
     for ( auto action : actions() ) {
