@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -38,7 +38,7 @@ public:
      *
      * Triggering this action emits clipboardItemActionTriggered() signal.
      */
-    void addClipboardItemAction(const QModelIndex &index, bool showImages);
+    void addClipboardItemAction(const QVariantMap &data, bool showImages);
 
     void clearClipboardItems();
 
@@ -77,6 +77,8 @@ protected:
 
     void leaveEvent(QEvent *event) override;
 
+    void inputMethodEvent(QInputMethodEvent *event) override;
+
 private:
     void clearActionsWithProperty(const char *property);
 
