@@ -118,6 +118,7 @@ private slots:
     void commandsGetSetCommands();
 
     void commandsImportExportCommands();
+    void commandsImportExportCommandsFixIndentation();
 
     void commandScreenshot();
 
@@ -257,7 +258,7 @@ private slots:
     void showHideActionHandlerDialog();
 
     void shortcutDialogAddShortcut();
-    void shortcutDialogAddTwoShortcut();
+    void shortcutDialogAddTwoShortcuts();
     void shortcutDialogChangeShortcut();
     void shortcutDialogSameShortcut();
     void shortcutDialogCancel();
@@ -272,6 +273,10 @@ private slots:
 
     void abortInputReader();
 
+    void changeAlwaysOnTop();
+
+    void networkGet();
+
 private:
     void clearServerErrors();
     int run(const QStringList &arguments, QByteArray *stdoutData = nullptr,
